@@ -9,6 +9,7 @@ import os
 import shutil
 import uuid
 from .tools import __try_to_set_owner as try_to_set_owner
+from .tools import measure_time
 try:
     from psycopg2 import IntegrityError
 except Exception:
@@ -16,6 +17,7 @@ except Exception:
 from .tools import _extract_python_libname
 from .tools import _exists_table
 from .tools import _execute_sql
+from .tools import measure_time
 from .odoo_config import get_conn_autoclose, manifest_file_names
 from .odoo_config import current_version
 from .odoo_config import get_settings
@@ -64,12 +66,14 @@ def delete_qweb(config, modules):
 
     with get_conn_autoclose(config) as cr:
         if modules != 'all':
-            cr.execute("select name from ir_module_module where name = %s", (modules,))
+            cr.execute("select name from ir_module_module where name = %s", (
+                modules,))
         else:
             cr.execute("select name from ir_module_module; ")
 
         def erase_view(view_id):
-            cr.execute("select id from ir_ui_view where inherit_id = %s;", (view_id, ))
+            cr.execute("select id from ir_ui_view where inherit_id = %s;", (
+                view_id, ))
             for child_view_id in [x[0] for x in cr.fetchall()]:
                 erase_view(child_view_id)
             cr.execute("""
@@ -83,18 +87,17 @@ def delete_qweb(config, modules):
             data_ids = [x[0] for x in cr.fetchall()]
 
             for data_id in data_ids:
-                cr.execute("delete from ir_model_data where id = %s", (data_id,))
+                cr.execute("delete from ir_model_data where id = %s", (
+                    data_id,))
 
             sp = 'sp' + uuid.uuid4().hex
-            cr.execute("savepoint {}".format(sp))
+            cr.execute(f"savepoint {sp}")
             try:
-                cr.execute("""
-                   delete from ir_ui_view where id = %s;
-                """, [view_id])
-                cr.execute("release savepoint {}".format(sp))
+                cr.execute("delete from ir_ui_view where id = %s;", [view_id])
+                cr.execute(f"release savepoint {sp}")
 
             except IntegrityError:
-                cr.execute("rollback to savepoint {}".format(sp))
+                cr.execute(f"rollback to savepoint {sp}")
 
         for module in cr.fetchall():
             if not DBModules.is_module_installed(module):
@@ -557,11 +560,12 @@ class Modules(object):
             all_modules_cache = self._get_modules()
         self.modules = all_modules_cache
 
+    @measure_time
     def _get_modules(self):
         modnames = set()
-        started = arrow.get()
         from .odoo_config import get_odoo_addons_paths
 
+        @measure_time
         def get_all_manifests():
             """
             Returns a list of full paths of all manifests
@@ -580,7 +584,6 @@ class Modules(object):
             modules[m.parent.name] = Module(m)
 
         # if directory is clear, we may cache
-        click.secho(f"Took: {(arrow.get() - started).total_seconds()}")
         return modules
 
     def is_git_clean(self):
@@ -681,7 +684,7 @@ class Modules(object):
 
     def get_all_auto_install_modules(self):
         auto_install_modules = []
-        for module in Modules()._get_modules():
+        for module in Modules().modules:
             try:
                 module = Module.get_by_name(module)
             except NotInAddonsPath:
@@ -890,16 +893,16 @@ class Module(object):
         if not self._manifest_dict:
             try:
                 content = self.manifest_path.read_text()
-                content = '\n'.join(filter(lambda x: not x.strip().startswith("#"), content.split("\n")))
-                return eval(content) # TODO safe
-            except SyntaxError:
-                click.secho("error at file: %s" % self.manifest_path, fg='red')
+                content = '\n'.join(filter(
+                    lambda x: not x.strip().startswith("#"),
+                    content.splitlines()))
+                self._manifest_dict = eval(content)  # TODO safe
+
+            except (SyntaxError, Exception):
+                click.secho((
+                    f"error at file: {self.manifest_path}"
+                ), fg='red')
                 raise
-            except Exception:
-                click.secho("error at file: %s" % self.manifest_path, fg='red')
-                raise
-            else:
-                self._manifest_dict = content
         return self._manifest_dict
 
     def __make_path_relative(self, path):
@@ -940,6 +943,10 @@ class Module(object):
 
     @classmethod
     def _get_by_name(cls, name):
+
+        if name in all_modules_cache:
+            return all_modules_cache[name]
+
         from .odoo_config import get_odoo_addons_paths
         if isinstance(name, Module):
             name = name.name
